@@ -1,7 +1,12 @@
 context("muhaz")
 
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
+
 skip_if_not_installed("muhaz")
-skip_if_not_installed("survival")  # does this skip with base R?
+skip_if_not_installed("survival") # does this skip with base R?
 
 library(muhaz)
 data(ovarian, package = "survival")
@@ -21,7 +26,6 @@ test_that("tidy.muhaz", {
 
 test_that("glance.muhaz", {
   gl <- glance(fit)
-  check_glance_outputs(gl)
+  check_glance_outputs(gl, strict = FALSE)
   check_dims(gl, expected_cols = 5)
 })
-
